@@ -15,8 +15,8 @@ import (
 	"flag"
 	"fmt"
 	"io"
-	"io/ioutil"
 	"os"
+	"path/filepath"
 	"runtime"
 	"strings"
 	"sync"
@@ -28,8 +28,6 @@ import (
 )
 
 var (
-	go1_8 bool
-
 	conc = flag.Int("conc", 1, "sets the level of concurrency for compression")
 	file = flag.String("bench.file", "", "bgzf file to read for benchmarking decompression")
 )
@@ -57,7 +55,7 @@ func TestEmpty(t *testing.T) {
 	if err != nil {
 		t.Fatalf("NewReader: %v", err)
 	}
-	b, err := ioutil.ReadAll(r)
+	b, err := io.ReadAll(r)
 	if err != nil {
 		t.Fatalf("ReadAll: %v", err)
 	}
@@ -79,8 +77,7 @@ func (r crippledReaderAt) ReadAt(b []byte, off int64) (int, error) {
 
 // TestEOF tests HasEOF can find the EOF magic block.
 func TestEOF(t *testing.T) {
-	// os.File cases
-	f, err := ioutil.TempFile(os.TempDir(), "bgzf_EOF_test_")
+	f, err := os.Create(filepath.Join(t.TempDir(), "data"))
 	if err != nil {
 		t.Fatalf("Create temp file: %v", err)
 	}
@@ -90,6 +87,10 @@ func TestEOF(t *testing.T) {
 		t.Fatalf("Writer.Close: %v", err)
 	}
 
+	if err := f.Close(); err != nil {
+		t.Fatalf("f.Close: %v", err)
+	}
+
 	f, err = os.Open(fname)
 	if err != nil {
 		t.Fatalf("Open temp file: %v", err)
@@ -101,19 +102,26 @@ func TestEOF(t *testing.T) {
 	if !ok {
 		t.Error("Expected EOF in os.File: not found.")
 	}
-
-	os.Remove(fname)
-
-	f, err = os.Open(os.TempDir())
-	if err != nil {
-		t.Fatalf("Open temp dir: %v", err)
+	if err := f.Close(); err != nil {
+		t.Fatalf("f.Close: %v", err)
 	}
-	ok, err = HasEOF(f)
-	if want := "read " + os.TempDir() + ": is a directory"; err.Error() != want {
-		t.Errorf("Expected error:%s got:%v", want, err)
-	}
-	if ok {
-		t.Error("Unexpected EOF in os.File IsDir: found.")
+
+	if runtime.GOOS != "windows" {
+		// NOTE: on Windows, os.Open is not allowed for directories.
+		f, err = os.Open(t.TempDir())
+		if err != nil {
+			t.Fatalf("Open temp dir: %v", err)
+		}
+		ok, err = HasEOF(f)
+		if want := "read " + t.TempDir() + ": is a directory"; err.Error() != want {
+			t.Errorf("Expected error:%s got:%v", want, err)
+		}
+		if ok {
+			t.Error("Unexpected EOF in os.File IsDir: found.")
+		}
+		if err := f.Close(); err != nil {
+			t.Fatalf("f.Close: %v", err)
+		}
 	}
 
 	// {bytes,strings}.Reader cases
@@ -219,7 +227,7 @@ func TestRoundTrip(t *testing.T) {
 }
 
 func readAllWrapper(r *Reader) ([]byte, error) {
-	return ioutil.ReadAll(r)
+	return io.ReadAll(r)
 }
 
 func readAllByByte(r *Reader) ([]byte, error) {
@@ -348,10 +356,6 @@ func readByByte(r *Reader, buf []byte) (n int, err error) {
 // See https://github.com/biogo/hts/issues/57
 func TestHeaderIssue57(t *testing.T) {
 	var stamp time.Time
-	if !go1_8 {
-		unixEpoch := time.Unix(0, 0)
-		stamp = unixEpoch
-	}
 
 	var buf bytes.Buffer
 	bg := NewWriter(&buf, *conc)
@@ -371,7 +375,7 @@ func TestHeaderIssue57(t *testing.T) {
 // TestRoundTripMultiSeek tests that bgzipping and then bgunzipping is the identity
 // function for a multiple member bgzf with an underlying Seeker.
 func TestRoundTripMultiSeek(t *testing.T) {
-	f, err := ioutil.TempFile(os.TempDir(), "bgzf_test_")
+	f, err := os.Create(filepath.Join(t.TempDir(), "data"))
 	if err != nil {
 		t.Fatalf("Create temp file: %v", err)
 	}
@@ -476,11 +480,15 @@ func TestRoundTripMultiSeek(t *testing.T) {
 	if err != io.EOF {
 		t.Errorf("Read: %v", err)
 	}
-	r.Close()
+	if err := r.Close(); err != nil {
+		t.Errorf("r.Close: %v", err)
+	}
+	if err := f.Close(); err != nil {
+		t.Errorf("f.Close: %v", err)
+	}
 	if string(b[:n]) != "payloadTwo" {
 		t.Errorf("payload is %q, want %q", string(b[:n]), "payloadTwo")
 	}
-	os.Remove(fname)
 }
 
 type errorReadSeeker struct {
@@ -1191,7 +1199,7 @@ func (z zero) Read(p []byte) (int, error) {
 }
 
 func TestWriteByteCount(t *testing.T) {
-	cw, _ := NewWriterLevel(ioutil.Discard, gzip.BestCompression, 4)
+	cw, _ := NewWriterLevel(io.Discard, gzip.BestCompression, 4)
 	defer cw.Close()
 	n, err := io.Copy(cw, &io.LimitedReader{R: new(zero), N: 100000})
 	if n != 100000 {
@@ -1237,7 +1245,7 @@ func TestSeekCacheReadahead(t *testing.T) {
 }
 
 func BenchmarkWrite(b *testing.B) {
-	bg := NewWriter(ioutil.Discard, *conc)
+	bg := NewWriter(io.Discard, *conc)
 	block := bytes.Repeat([]byte("repeated"), 50)
 	for i := 0; i < b.N; i++ {
 		for j := 0; j < 1000000; j++ {
@@ -1261,7 +1269,7 @@ func BenchmarkRead(b *testing.B) {
 	b.ResetTimer()
 
 	for i := 0; i < b.N; i++ {
-		f.Seek(0, os.SEEK_SET)
+		f.Seek(0, io.SeekStart)
 		bg, err := NewReader(f, *conc)
 		if err != nil {
 			b.Fatalf("bgzf open failed: %v", err)
