@@ -362,9 +362,10 @@ type Reader struct {
 
 // NewReader returns a new BGZF reader.
 //
-// The number of concurrent read decompressors is specified by rd.
-// If rd is 0, GOMAXPROCS concurrent will be created. The returned
-// Reader should be closed after use to avoid leaking resources.
+// The number of concurrent read decompressors is specified by rd. If rd
+// is 0, GOMAXPROCS concurrent will be created. If rd is 1, blocks will
+// be read synchronously without readahead. The returned Reader should
+// be closed after use to avoid leaking resources.
 func NewReader(r io.Reader, rd int) (*Reader, error) {
 	if rd == 0 {
 		rd = runtime.GOMAXPROCS(0)
@@ -462,24 +463,38 @@ func (bg *Reader) Seek(off Offset) error {
 					blk, err := dec.wait()
 					if err == nil {
 						bg.keep(blk)
+						if blk.Base() == off.File {
+							// This decompressor had the block we
+							// wanted.
+							bg.current = blk
+							bg.control <- bg.current.NextBase()
+							bg.waiting <- dec
+							dec = nil
+						}
 					}
 				}
 			}
-			bg.current, bg.err = dec.
-				using(bg.current).
-				nextBlockAt(off.File, rs).
-				wait()
-			if bg.dec == nil {
-				select {
-				case <-bg.control:
-				default:
+			if dec != nil {
+				// Synchronously decompress the requested block using
+				// the selected decompressor. Not necessary if that
+				// decompressor had the block ready, as determined
+				// above.
+				bg.current, bg.err = dec.
+					using(bg.current).
+					nextBlockAt(off.File, rs).
+					wait()
+				if bg.dec == nil {
+					select {
+					case <-bg.control:
+					default:
+					}
+					bg.control <- bg.current.NextBase()
+					bg.waiting <- dec
+				}
+				bg.Header = bg.current.header()
+				if bg.err != nil {
+					return bg.err
 				}
-				bg.control <- bg.current.NextBase()
-				bg.waiting <- dec
-			}
-			bg.Header = bg.current.header()
-			if bg.err != nil {
-				return bg.err
 			}
 		}
 	}
@@ -560,6 +575,40 @@ func (bg *Reader) Read(p []byte) (int, error) {
 	return n, bg.err
 }
 
+// ReadByte implements the io.ByteReader interface.
+func (bg *Reader) ReadByte() (byte, error) {
+	if bg.err != nil {
+		return 0, bg.err
+	}
+
+	// Discard leading empty blocks. This is an indexing
+	// optimisation to avoid retaining useless members
+	// in a BAI/CSI.
+	for bg.current.len() == 0 {
+		bg.err = bg.nextBlock()
+		if bg.err != nil {
+			return 0, bg.err
+		}
+	}
+
+	bg.lastChunk.Begin = bg.current.txOffset()
+
+	var b byte
+	b, bg.err = bg.current.ReadByte()
+	if bg.err == io.EOF {
+		if bg.Blocked {
+			bg.err = nil
+			bg.lastChunk.End = bg.current.txOffset()
+			return b, io.EOF
+		}
+
+		bg.err = bg.nextBlock()
+	}
+
+	bg.lastChunk.End = bg.current.txOffset()
+	return b, bg.err
+}
+
 // nextBlock swaps the current decompressed block for the next
 // in the stream. If the block is available from the cache
 // no additional work is done, otherwise a decompressor is
